package services

import (
	"fmt"
	"hongze/hz_crm_eta/models/crm"
	"hongze/hz_crm_eta/models/eta"
	"hongze/hz_crm_eta/utils"
	"time"
)

// HandleSyncSysRole 同步系统角色
func HandleSyncSysRole(source int, roleName string) (err error) {
	// 角色名称唯一, 所以用角色名称做同步
	if roleName == "" {
		return
	}
	if source != utils.SOURCE_CRM_FLAG && source != utils.SOURCE_ETA_FLAG {
		return
	}

	// CRM
	if source == utils.SOURCE_CRM_FLAG {
		// 获取角色不存在, 则表示CRM删除了该角色, 需删除对应ETA角色
		crmRole, e := crm.GetSysRoleByName(roleName)
		if e != nil {
			if e != utils.ErrNoRow {
				err = fmt.Errorf("获取CRM角色信息失败, Err: " + e.Error())
				return
			}
			_ = eta.DeleteRoleByName(roleName)
			return
		}

		// 获取ETA对应角色, 存在则更新, 否则新增
		etaRole, e := eta.GetSysRoleByName(roleName)
		if e != nil {
			if e != utils.ErrNoRow {
				err = fmt.Errorf("获取ETA对应角色信息失败, Err: " + e.Error())
				return
			}
			// 新增
			newRole := new(eta.SysRole)
			newRole.RoleName = crmRole.RoleName
			newRole.RoleType = crmRole.RoleType
			newRole.RoleTypeCode = crmRole.RoleTypeCode
			newRole.RoleLevel = crmRole.RoleLevel
			newRole.CreateTime = time.Now().Local()
			newRole.ModifyTime = time.Now().Local()
			if e = newRole.Create(); e != nil {
				err = fmt.Errorf("新增ETA对应角色失败, Err: " + e.Error())
				return
			}
		}
		// 更新
		etaRole.RoleName = crmRole.RoleName
		etaRole.RoleType = crmRole.RoleType
		etaRole.RoleTypeCode = crmRole.RoleTypeCode
		etaRole.RoleLevel = crmRole.RoleLevel
		etaRole.ModifyTime = time.Now().Local()
		cols := []string{"RoleName", "RoleType", "RoleTypeCode", "RoleLevel", "ModifyTime"}
		e = etaRole.Update(cols)
		if e != nil {
			err = fmt.Errorf("更新ETA对应角色失败, Err: " + e.Error())
		}
		return
	}

	// ETA
	etaRole, e := eta.GetSysRoleByName(roleName)
	if e != nil {
		if e != utils.ErrNoRow {
			err = fmt.Errorf("获取ETA角色信息失败, Err: " + e.Error())
			return
		}
		_ = crm.DeleteRoleByName(roleName)
		return
	}

	crmRole, e := crm.GetSysRoleByName(roleName)
	if e != nil {
		if e != utils.ErrNoRow {
			err = fmt.Errorf("获取CRM对应角色信息失败, Err: " + e.Error())
			return
		}
		// 新增
		newRole := new(crm.SysRole)
		newRole.RoleName = etaRole.RoleName
		newRole.RoleType = etaRole.RoleType
		newRole.RoleTypeCode = etaRole.RoleTypeCode
		newRole.RoleLevel = etaRole.RoleLevel
		newRole.CreateTime = time.Now().Local()
		newRole.ModifyTime = time.Now().Local()
		if e = newRole.Create(); e != nil {
			err = fmt.Errorf("新增CRM对应角色失败, Err: " + e.Error())
			return
		}
	}
	// 更新
	crmRole.RoleName = etaRole.RoleName
	crmRole.RoleType = etaRole.RoleType
	crmRole.RoleTypeCode = etaRole.RoleTypeCode
	crmRole.RoleLevel = etaRole.RoleLevel
	crmRole.ModifyTime = time.Now().Local()
	cols := []string{"RoleName", "RoleType", "RoleTypeCode", "RoleLevel", "ModifyTime"}
	e = crmRole.Update(cols)
	if e != nil {
		err = fmt.Errorf("更新CRM对应角色失败, Err: " + e.Error())
	}
	return
}

// HandleSyncAdminFromCrm 同步系统用户
func HandleSyncAdminFromCrm(source int, adminName string) (err error) {
	return
}
